<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>APngWriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_apng.cpp" line="225"/>
        <source>Scale</source>
        <translation>Масштаб</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_apng.cpp" line="226"/>
        <source>Looping</source>
        <translation>Зациклить</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_apng.cpp" line="227"/>
        <source>Write as .png</source>
        <translation>Записать в формате .png</translation>
    </message>
</context>
<context>
    <name>AviWriterProperties</name>
    <message>
        <location filename="../../image/avi/tiio_avi.cpp" line="1182"/>
        <source>Codec</source>
        <translation>Кодек</translation>
    </message>
    <message>
        <location filename="../../image/avi/tiio_avi.cpp" line="1183"/>
        <source>Uncompressed</source>
        <translation>Без сжатия</translation>
    </message>
</context>
<context>
    <name>ExrWriterProperties</name>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="290"/>
        <source>Bits Per Pixel</source>
        <translatorcomment>глубина цвета</translatorcomment>
        <translation>Бит на пиксель</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="292"/>
        <source>48(RGB Half Float)</source>
        <translation>48(RGB Плавающая  половина)</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="293"/>
        <source>64(RGBA Half Float)</source>
        <translation>54(RGB Плавающая  половина)</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="294"/>
        <source>96(RGB Float)</source>
        <translation>96(RGB Плавающая)</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="295"/>
        <source>128(RGBA Float)</source>
        <translation>128(RGBA Плавающая)</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="299"/>
        <source>Compression Type</source>
        <translation>Сжатый тип</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="301"/>
        <source>No compression</source>
        <translation>Не сжатый</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="304"/>
        <source>Run Length Encoding (RLE)</source>
        <translation>Выполнение длительности кодированияия (ВДК)</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="307"/>
        <source>ZIP compression per Scanline (ZIPS)</source>
        <translation>Zip-cжатие  по линии сканирования (ZIPS)</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="310"/>
        <source>ZIP compression per scanline band (ZIP)</source>
        <translation>Zip-cжатие  на полосу сканирования (ZIP)</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="313"/>
        <source>PIZ-based wavelet compression (PIZ)</source>
        <translation>Вейвлет-сжатие на основе PIZ (PIZ)</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="315"/>
        <source>Storage Type</source>
        <translation>Тип хранилища</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="316"/>
        <source>Scan-line based</source>
        <translation>Сканирование на основе линии</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="317"/>
        <source>Tile based</source>
        <translation>На основе плитки</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="319"/>
        <source>Color Space Gamma</source>
        <translation>Гамма цветового пространства</translation>
    </message>
</context>
<context>
    <name>FFMovWriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_ff_mov.cpp" line="234"/>
        <source>Quality</source>
        <translation>Качество</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_ff_mov.cpp" line="235"/>
        <source>Scale</source>
        <translation>Масштаб</translation>
    </message>
</context>
<context>
    <name>GifWriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="310"/>
        <source>Global Palette</source>
        <translation>Глобальная палитра</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="311"/>
        <source>Global Palette + Sierra Dither</source>
        <translation>Глобальная палитра + сглаживание Сиерра</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="312"/>
        <source>Global Palette + Bayer2 Dither</source>
        <translation>Глобальная палитра + сглаживание по Байеру 2</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="313"/>
        <source>Global Palette + Bayer1 Dither</source>
        <translation>Глобальная палитра + сглаживание по Байеру 1</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="314"/>
        <source>Diff Palette</source>
        <translation>Палитра различий</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="315"/>
        <source>Diff Palette + Sierra Dither</source>
        <translation>Палитра различий+ сглаживание Сиерра</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="316"/>
        <source>Diff Palette + Bayer2 Dither</source>
        <translation>Палитра различий+ сглаживание по Байеру 2</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="317"/>
        <source>Diff Palette + Bayer1 Dither</source>
        <translation>Палитра различий+ сглаживание по Байеру 1</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="318"/>
        <source>New Pal Per Frame</source>
        <translation>Создайте новую палитру кадров</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="319"/>
        <source>New Pal Per Frame + Sierra Dither</source>
        <translation>Создайте новую палитру кадров+ сглаживание Сиерра</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="320"/>
        <source>New Pal Per Frame + Bayer2 Dither</source>
        <translation>Создайте новую палитру кадров+ сглаживание по Байеру 2</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="321"/>
        <source>New Pal Per Frame + Bayer1 Dither</source>
        <translation>Создайте новую палитру кадров+ сглаживание по Байеру 1</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="322"/>
        <source>Opaque, Dither, 256 Colors Only</source>
        <translation>Непрозрачный, размытый, только 256 цветов</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="335"/>
        <source>Scale</source>
        <translation>Масштаб</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="336"/>
        <source>Looping</source>
        <translation>Зациклить</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="337"/>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="338"/>
        <source>Max Colors</source>
        <translation>Максимальное количество цветов</translation>
    </message>
    <message>
        <source>Generate Palette</source>
        <translation type="vanished">Создать палитру</translation>
    </message>
</context>
<context>
    <name>Mp4WriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_mp4.cpp" line="234"/>
        <source>Quality</source>
        <translation>Качество</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_mp4.cpp" line="235"/>
        <source>Scale</source>
        <translation>Масштаб</translation>
    </message>
</context>
<context>
    <name>PngWriterProperties</name>
    <message>
        <location filename="../../image/png/tiio_png.cpp" line="757"/>
        <source>Alpha Channel</source>
        <translation>Альфа канал</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_ffmpeg.cpp" line="172"/>
        <source>FFmpeg returned error-code: %1</source>
        <translation>FFmpeg вернул код ошибки: %1</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_ffmpeg.cpp" line="160"/>
        <location filename="../../image/ffmpeg/tiio_ffmpeg.cpp" line="176"/>
        <source>FFmpeg timed out.
Please check the file for errors.
If the file doesn&apos;t play or is incomplete, 
Please try raising the FFmpeg timeout in Preferences.</source>
        <translation>Время ожидания FFmpeg.
Пожалуйста, проверьте файл на наличие ошибок.
Если файл не воспроизводится или является неполным,
попробуйте увеличить время ожидания FFmpeg в настройках.</translation>
    </message>
</context>
<context>
    <name>SgiWriterProperties</name>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1229"/>
        <source>Bits Per Pixel</source>
        <translation>Битов на пиксель</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1230"/>
        <source>24 bits</source>
        <translation>24 бита</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1231"/>
        <source>32 bits</source>
        <translation>32 бита</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1232"/>
        <source>48 bits</source>
        <translation>48 бит</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1233"/>
        <source>64 bits</source>
        <translation>64 бита</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1234"/>
        <source>8 bits (Greyscale)</source>
        <translation>8 бита (оттенки серого)</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1235"/>
        <source>Endianness</source>
        <translation>Endianness</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1236"/>
        <source>Big Endian</source>
        <translation>Big Endian</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1237"/>
        <source>Little Endian</source>
        <translation>Little Endian</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1238"/>
        <source>RLE-Compressed</source>
        <translation>RLE-сжатие</translation>
    </message>
</context>
<context>
    <name>SpriteWriterProperties</name>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="313"/>
        <source>Top Padding</source>
        <translation>Заполнение сверху</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="314"/>
        <source>Bottom Padding</source>
        <translation>Заполнение снизу</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="315"/>
        <source>Left Padding</source>
        <translation>Заполнение слева</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="316"/>
        <source>Right Padding</source>
        <translation>Заполнение справа</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="317"/>
        <source>Scale</source>
        <translation>Масштаб</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="318"/>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="319"/>
        <source>Grid</source>
        <translation>Сетка</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="320"/>
        <source>Vertical</source>
        <translation>Вертикально</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="321"/>
        <source>Horizontal</source>
        <translation>Горизонтально</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="322"/>
        <source>Individual</source>
        <translation>Индивидуально</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="323"/>
        <source>Trim Empty Space</source>
        <translation>Обрезать пустое пространство</translation>
    </message>
</context>
<context>
    <name>SvgWriterProperties</name>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1969"/>
        <source>Stroke Mode</source>
        <translation>Режим обводки</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1970"/>
        <source>Outline Quality</source>
        <translation>Качество контура</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1971"/>
        <source>Centerline</source>
        <translation>Осевая линия</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1972"/>
        <source>Outline</source>
        <translation>Контур</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1973"/>
        <source>High</source>
        <translation>Высокая</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1974"/>
        <source>Medium</source>
        <translation>Средняя</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1975"/>
        <source>Low</source>
        <translation>Низкая</translation>
    </message>
</context>
<context>
    <name>TgaWriterProperties</name>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="523"/>
        <source>Bits Per Pixel</source>
        <translation>Битов на пиксель</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="524"/>
        <source>16 bits</source>
        <translation>16 битов</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="525"/>
        <source>24 bits</source>
        <translation>24 бита</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="526"/>
        <source>32 bits</source>
        <translation>32 бита</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="527"/>
        <source>Compression</source>
        <translation>Сжатие</translation>
    </message>
</context>
<context>
    <name>TifWriterProperties</name>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="730"/>
        <source>Byte Ordering</source>
        <translation>Порядок следования байтов</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="731"/>
        <source>Compression Type</source>
        <translation>Тип сжатия</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="732"/>
        <source>Bits Per Pixel</source>
        <translation>Битов на пиксель</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="733"/>
        <source>24(RGB)</source>
        <translation>24(RGB)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="734"/>
        <source>48(RGB)</source>
        <translation>48(RGB)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="735"/>
        <source> 1(BW)</source>
        <translation> 1(ЧБ)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="736"/>
        <source> 8(GREYTONES)</source>
        <translation> 8(ОТТЕНКИСЕРОГО)</translation>
    </message>
    <message>
        <source>32(RGBM)</source>
        <translation type="obsolete">32(RGBA)</translation>
    </message>
    <message>
        <source>64(RGBM)</source>
        <translation type="obsolete">64(RGBA)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="737"/>
        <source>32(RGBA)</source>
        <translation>32(RGBA)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="738"/>
        <source>64(RGBA)</source>
        <translation>64(RGBA)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="739"/>
        <source>Orientation</source>
        <translation>Ориентация</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="740"/>
        <source>Top Left</source>
        <translation>Сверху слева</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="741"/>
        <source>Top Right</source>
        <translation>Сверху справа</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="742"/>
        <source>Bottom Right</source>
        <translation>Снизу справа</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="743"/>
        <source>Bottom Left</source>
        <translation>Снизу слева</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="744"/>
        <source>Left Top</source>
        <translation>Слева сверху</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="745"/>
        <source>Left Bottom</source>
        <translation>Слева снизу</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="746"/>
        <source>Right Top</source>
        <translation>Справа снизу</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="747"/>
        <source>Right Bottom</source>
        <translation>Справа снизу</translation>
    </message>
</context>
<context>
    <name>Tiio::AviWriterProperties</name>
    <message>
        <source>Codec</source>
        <translation type="vanished">Кодек</translation>
    </message>
    <message>
        <source>Uncompressed</source>
        <translation type="vanished">Без сжатия</translation>
    </message>
</context>
<context>
    <name>Tiio::PngWriterProperties</name>
    <message>
        <source>Alpha Channel</source>
        <translation type="vanished">Альфа канал</translation>
    </message>
</context>
<context>
    <name>Tiio::SgiWriterProperties</name>
    <message>
        <source>Bits Per Pixel</source>
        <translation type="vanished">Битов на пиксель</translation>
    </message>
    <message>
        <source>24 bits</source>
        <translation type="vanished">24 бита</translation>
    </message>
    <message>
        <source>32 bits</source>
        <translation type="vanished">32 бита</translation>
    </message>
    <message>
        <source>48 bits</source>
        <translation type="vanished">48 бита</translation>
    </message>
    <message>
        <source>64 bits</source>
        <translation type="vanished">64 бита</translation>
    </message>
    <message>
        <source>8 bits (Greyscale)</source>
        <translation type="vanished">8 бита (оттенки серого)</translation>
    </message>
    <message>
        <source>Endianness</source>
        <translation type="vanished">Порядок байтов</translation>
    </message>
    <message>
        <source>Big Endian</source>
        <translation type="vanished">От старшего к младшему</translation>
    </message>
    <message>
        <source>Little Endian</source>
        <translation type="vanished">От младшего к старшему</translation>
    </message>
    <message>
        <source>RLE-Compressed</source>
        <translation type="vanished">RLE-сжатие</translation>
    </message>
</context>
<context>
    <name>Tiio::SvgWriterProperties</name>
    <message>
        <source>Stroke Mode</source>
        <translation type="vanished">Режим обводки</translation>
    </message>
    <message>
        <source>Outline Quality</source>
        <translation type="vanished">Качество контура</translation>
    </message>
    <message>
        <source>Centerline</source>
        <translation type="vanished">Осевая линия</translation>
    </message>
    <message>
        <source>Outline</source>
        <translation type="vanished">Контур</translation>
    </message>
    <message>
        <source>High</source>
        <translation type="vanished">Высокая</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation type="vanished">Средняя</translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="vanished">Низкая</translation>
    </message>
</context>
<context>
    <name>Tiio::TgaWriterProperties</name>
    <message>
        <source>Bits Per Pixel</source>
        <translation type="vanished">Битов на пиксель</translation>
    </message>
    <message>
        <source>16 bits</source>
        <translation type="vanished">16 битов</translation>
    </message>
    <message>
        <source>24 bits</source>
        <translation type="vanished">24 бита</translation>
    </message>
    <message>
        <source>32 bits</source>
        <translation type="vanished">32 бита</translation>
    </message>
    <message>
        <source>Compression</source>
        <translation type="vanished">Сжатие</translation>
    </message>
</context>
<context>
    <name>Tiio::TifWriterProperties</name>
    <message>
        <source>Byte Ordering</source>
        <translation type="vanished">Порядок следования байтов</translation>
    </message>
    <message>
        <source>Compression Type</source>
        <translation type="vanished">Тип сжатия</translation>
    </message>
    <message>
        <source>Bits Per Pixel</source>
        <translation type="vanished">Битов на пиксель</translation>
    </message>
    <message>
        <source>24(RGB)</source>
        <translation type="vanished">24(RGB)</translation>
    </message>
    <message>
        <source>48(RGB)</source>
        <translation type="vanished">48(RGB)</translation>
    </message>
    <message>
        <source> 1(BW)</source>
        <translation type="vanished"> 1(ЧБ)</translation>
    </message>
    <message>
        <source> 8(GREYTONES)</source>
        <translation type="vanished"> 8(ОТТЕНКИСЕРОГО)</translation>
    </message>
    <message>
        <source>32(RGBM)</source>
        <translation type="vanished">32(RGBA)</translation>
    </message>
    <message>
        <source>64(RGBM)</source>
        <translation type="vanished">64(RGBA)</translation>
    </message>
    <message>
        <source>Orientation</source>
        <translation type="vanished">Расположение</translation>
    </message>
    <message>
        <source>Top Left</source>
        <translation type="vanished">Сверху слева</translation>
    </message>
    <message>
        <source>Top Right</source>
        <translation type="vanished">Сверху справа</translation>
    </message>
    <message>
        <source>Bottom Right</source>
        <translation type="vanished">Снизу справа</translation>
    </message>
    <message>
        <source>Bottom Left</source>
        <translation type="vanished">Снизу слева</translation>
    </message>
    <message>
        <source>Left Top</source>
        <translation type="vanished">Слева сверху</translation>
    </message>
    <message>
        <source>Left Bottom</source>
        <translation type="vanished">Слева снизу</translation>
    </message>
    <message>
        <source>Right Top</source>
        <translation type="vanished">Справа снизу</translation>
    </message>
    <message>
        <source>Right Bottom</source>
        <translation type="vanished">Справа снизу</translation>
    </message>
</context>
<context>
    <name>WebmWriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_webm.cpp" line="235"/>
        <source>Quality</source>
        <translation>Качество</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_webm.cpp" line="236"/>
        <source>Scale</source>
        <translation>Масштаб</translation>
    </message>
</context>
</TS>
